pyLBM.elements.Circle
=====================

.. currentmodule:: pyLBM.elements

.. autoclass:: Circle

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Circle.distance
         Circle.get_bounds
         Circle.point_inside
         Circle.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Circle.number_of_bounds

